import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import SerbiaCountryCode from '@/types/table/serbiaCountryCode';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface SerbiaCountryCodeData extends SerbiaCountryCode {
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class SerbiaCountryCodeController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<SerbiaCountryCodeData>>(API_CONTEXT + '/app/serbiaCountryCode/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<SerbiaCountryCodeData>(API_CONTEXT + '/app/serbiaCountryCode/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/serbiaCountryCode/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/serbiaCountryCode/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/serbiaCountryCode/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/serbiaCountryCode/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/serbiaCountryCode/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/serbiaCountryCode/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/serbiaCountryCode/deleteBatch', params, httpOptions);
  }
}
